import 'dart:ui';

extension ColorExtensions on Color {
  static fromHex(String hex, {double? opacity}) {
    hex = hex.replaceAll('#', '').toUpperCase();

    if (hex.length == 3) {
      hex = hex.split('').map((char) => char * 2).join('');
    }

    if (hex.length == 6) {
      hex = '${hex}FF';
    }

    assert(hex.length == 8, 'Invalid hex color length');

    final int value = int.parse(hex, radix: 16);
    final int red = (value >> 24) & 0xFF;
    final int green = (value >> 16) & 0xFF;
    final int blue = (value >> 8) & 0xFF;
    final int alpha = value & 0xFF;

    return Color.fromARGB(opacity != null ? (255.0 * opacity).round() : alpha, red, green, blue);
  }

  Color applyOpacity(double opacity) {
    final alphaValue = opacity.clamp(0.0, 1.0);

    // Check if `withValues` is available (Flutter 3.29+)
    try {
      return withValues(alpha: alphaValue);
    } catch (e) {
      // Fallback to `withOpacity()` for older versions
      // ignore: deprecated_member_use
      return withOpacity(opacity);
    }
  }
}