import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class SystemChromeHelpers {

  static void updateSystemChrome({required Brightness brightness, required BuildContext context}) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      if (Platform.isAndroid) {
        _updateAndroidSystemChrome(brightness: brightness == Brightness.dark ? Brightness.light : Brightness.dark, context: context);
      } else {
        _updateIosSystemChrome(brightness: brightness, context: context);
      }
    });
  }

  static void _updateIosSystemChrome({required Brightness brightness, required BuildContext context}) {
    SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
      statusBarColor: Colors.transparent,
      statusBarBrightness: brightness,
    ));
  }

  static void _updateAndroidSystemChrome({required Brightness brightness, required BuildContext context}) {
    try {
      var isGestureNavigation = MediaQuery.of(context).systemGestureInsets.left > 0;

      if (isGestureNavigation) {
        SystemChrome.setEnabledSystemUIMode(SystemUiMode.edgeToEdge);
        // Transparent nav bar with white divider for gesture navigation
        SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
          systemNavigationBarContrastEnforced: true,
          systemNavigationBarColor: Colors.white.withAlpha(1),
          systemNavigationBarIconBrightness: Brightness.light,
          systemNavigationBarDividerColor: Colors.transparent,
          statusBarColor: Colors.transparent,
          statusBarIconBrightness: brightness, // For Android
        ));
      } else {
        SystemChrome.setEnabledSystemUIMode(SystemUiMode.edgeToEdge, overlays: [SystemUiOverlay.top]);
        // Black nav bar with white icons/text for button navigation
        SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
          systemNavigationBarContrastEnforced: true,
          systemNavigationBarColor: Colors.black,
          systemNavigationBarIconBrightness: Brightness.light,
          systemNavigationBarDividerColor: Colors.black,
          statusBarColor: Colors.transparent,
          statusBarIconBrightness: brightness, // For Android
        ));
      }
    } on PlatformException catch (e) {
      // ignore: avoid_print
      print("Error detecting navigation mode: $e");
    }
  }
}

extension SystemChromeStyleExtension on BuildContext {
  void applyDarkTextStatusBar() {
    SystemChromeHelpers.updateSystemChrome(brightness: Brightness.light, context: this);
  }

  void applyLightTextStatusBar() {
    SystemChromeHelpers.updateSystemChrome(brightness: Brightness.dark, context: this);
  }
}